@@ -227,11 +227,13 @@ g_synaptics_is_tapping_enabled (GSynaptics *synaptics)
 
 	if (priv->synclient)
 	{
-		return g_synaptics_get_value_from_synclient ("MaxTapTime") > 0;
+		return (g_synaptics_get_value_from_synclient ("MaxTapTime") > 0 &&
+			g_synaptics_get_value_from_synclient ("TapButton1") > 0);
 	}
 	else
 	{
-		return SYNSHM(synaptics)->tap_time > 0;
+		return SYNSHM(synaptics)->tap_time > 0 &&
+			SYNSHM(synaptics)->tap_action[OneFinger] > 0; /* F1_TAP */
 	}
 }
 
@@ -881,6 +883,37 @@ g_synaptics_set_button_for_tap (GSynaptics *synaptics, TapType tap, Button butto
 	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
 	if (!g_synaptics_is_valid(synaptics))
 		return;
+
+	if (priv->synclient)
+	{
+	    gchar *command;
+
+	    if (tap >= OneFinger)
+	    {
+		command = g_strdup_printf ("synclient TapButton%d=%d",
+			tap - OneFinger + 1, button);
+	    } else
+	    {
+		char *corner;
+		switch (tap)
+		{
+		    case RightTop: corner ="RT"; break;
+		    case LeftTop: corner ="LT"; break;
+		    case RightBottom: corner ="RB"; break;
+		    case LeftBottom: corner ="LB"; break;
+		    default:
+				     return;
+		}
+		command = g_strdup_printf ("synclient %sCornerButton=%d",
+			corner, button);
+	    }
+	    g_spawn_command_line_async (command, NULL);
+	    g_free (command);
+	}
+	else
+	{
+	    SYNSHM(synaptics)->tap_action[tap] = button;
+	}
 }
 
 void
