@@ -221,10 +221,11 @@ cb_tapping_toggled (GtkToggleButton *button, GladeXML *dialog)
 	
 	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
 
-	if (!check)
-		time = 0;
-
 	g_synaptics_set_tap_time (synaptics, time);
+        /* Default 1/2/3 finger tap settings */
+	g_synaptics_set_button_for_tap(synaptics, OneFinger, check ? 1 : 0);
+	g_synaptics_set_button_for_tap(synaptics, TwoFingers, check ? 3 : 0);
+	g_synaptics_set_button_for_tap(synaptics, ThreeFingers, check ? 2 : 0);
 	gconf_client_set_int (gconf, MAXTAPTIME_KEY, time, NULL);
 }
 
